package com.dhcc.finance.main.service;

import java.util.List;

import com.dhcc.common.model.CurrencyMeta;
import com.dhcc.common.model.response.RestfulResponse;
import com.dhcc.finance.main.domain.CwHsGlorgbook;
import com.dhcc.finance.main.domain.CwHsSubcodemap;
import com.github.pagehelper.PageInfo;

public interface CwHsGlorgbookService {
	/**
	 * 功能描述
	 * @param pageNum
	 * @param pageSize
	 * @param navigatePages
	 * @return RestfulResponse<PageInfo<CwHsGlorgbook>,CurrencyMeta>
	 * @author huangpeng
	 * @param glorgbookCode 
	 * @date 2019年7月26日 下午5:27:28
	 * 修改日志
	 */
	RestfulResponse<PageInfo<CwHsGlorgbook>, CurrencyMeta> searchCwHsGlorgbookAllData(int pageNum, int pageSize,
			int navigatePages, String glorgbookCode);
	/**
	 * 功能描述
	 * @return RestfulResponse<List<CwHsGlorgbook>,CurrencyMeta>
	 * @author huangpeng
	 * @date 2019年7月26日 下午10:05:52
	 * 修改日志
	 */
	RestfulResponse<List<CwHsGlorgbook>, CurrencyMeta> searchAllData();
	 /**
     * Title: deletCwHsGlorgbookinfo <br/>  
     * Description: TODO按照帐套主键删除帐套<br/>
     * @author lipeng 
     * @return 
     * @date 2019年7月27日 上午10:23:18
     */
    RestfulResponse<Object, CurrencyMeta> deletCwHsGlorgbookinfo(List<String>  IdList);
    /**
     * Title  新增估值导出估值账套对照表
     * Description: TODO <br/>
     * @author lipeng 
     * @param cwHsGlorgbook
     * @return RestfulResponse<Object,CurrencyMeta>
     * @date 2019年7月27日 下午2:20:52
     */
    RestfulResponse<Object, CurrencyMeta> addcwHsGlorgbook(CwHsGlorgbook  cwHsGlorgbook);

    /**
     * Title  修正估值导出估值账套对照表 
     * Description: TODO <br/>
     * @author lipeng 
     * @param cwHsGlorgbook
     * @return RestfulResponse<Object,CurrencyMeta>
     * @date 2019年7月27日 下午2:20:52
     */
    RestfulResponse<Object, CurrencyMeta> updatacwHsGlorgbook(CwHsGlorgbook  cwHsGlorgbook);
    /**
	 * Title: searchCwGlVoucherAllData <br/>  
	 * Description:TODO 按照productId 查询帐套的信息
	 * @author lipeng 
	 * @param pageNum
	 * @param pageSize
	 * @param navigatePages
	 * @param subcode
	 * @param subcodev
	 * @return RestfulResponse<PageInfo<CwHsSubcodemap>,CurrencyMeta>
	 * @date 2019年7月26日 下午5:34:37
	 */
	RestfulResponse<PageInfo<CwHsSubcodemap>, CurrencyMeta> selectCwHsGlorgbookAndCwHsSub(int pageNum, int pageSize, int navigatePages,
			String  productId,String subCode,String subCodeV);
	/**
	 * Title: searchCwGlVoucherAllData <br/>  
	 * Description:TODO 按照批量插入帐套科目信息
	 * @author lipeng 
	 * @param pageNum
	 * @param pageSize
	 * @param navigatePages
	 * @param subcode
	 * @param subcodev
	 * @return RestfulResponse<PageInfo<CwHsSubcodemap>,CurrencyMeta>
	 * @date 2019年7月26日 下午5:34:37
	 */
	RestfulResponse<Object, CurrencyMeta> insertForBatch(String  productId);
	/**
	 * Title: selectCwHsGlorgbookCount <br/>  
	 * Description: TODO 按照producId查询帐套对应的科目数<br/>
	 * @author lipeng 
	 * @param productId
	 * @return RestfulResponse<Object,CurrencyMeta>
	 * @date 2019年7月29日 上午10:30:14
	 */
	RestfulResponse<Object, CurrencyMeta> selectCwHsGlorgbookCount(String  productId);
}
